==> umya-spreadsheet-0.4.1.crate: umya-spreadsheet-0.4.1/src/structs/drawing/charts/format_code.rs <==
// c:formatCode
use writer::driver::*;
use quick_xml::Reader;
use quick_xml::events::{Event, BytesStart};
use quick_xml::Writer;
use std::io::Cursor;

#[derive(Default, Debug)]
pub struct FormatCode {
    text: String,
}
impl FormatCode {
    pub fn get_text(&self)-> &str {
        &self.text
    }

    pub fn set_text<S: Into<String>>(&mut self, value:S)-> &mut FormatCode {
        self.text = value.into();
        self
    }

    pub(crate) fn set_attributes(
        &mut self,
        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
        _e:&BytesStart
    ) {
        let mut buf = Vec::new();
        loop {
            match reader.read_event(&mut buf) {
                Ok(Event::Text(e)) => {
                    self.set_text(e.unescape_and_decode(&reader).unwrap());
                }, 
                Ok(Event::End(ref e)) => {
                    match e.name() {
                        b"c:formatCode" => return,
                        _ => (),
                    }
                },
                Ok(Event::Eof) => panic!("Error not find {} end element", "c:formatCode"),
                Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
                _ => (),
            }
            buf.clear();
        }
    }

    pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
        // c:formatCode
        write_start_tag(writer, "c:formatCode", vec![], false);
        write_text_node(writer, &self.text);
        write_end_tag(writer, "c:formatCode");
    }
}

==> umya-spreadsheet-0.4.2.crate: umya-spreadsheet-0.4.2/src/structs/drawing/charts/format_code.rs <==
// c:formatCode
use writer::driver::*;
use quick_xml::Reader;
use quick_xml::events::{Event, BytesStart};
use quick_xml::Writer;
use std::io::Cursor;

#[derive(Default, Debug)]
pub struct FormatCode {
    text: String,
}
impl FormatCode {
    pub fn get_text(&self)-> &str {
        &self.text
    }

    pub fn set_text<S: Into<String>>(&mut self, value:S)-> &mut FormatCode {
        self.text = value.into();
        self
    }

    pub(crate) fn set_attributes<R: std::io::BufRead>(
        &mut self,
        reader:&mut Reader<R>,
        _e:&BytesStart
    ) {
        let mut buf = Vec::new();
        loop {
            match reader.read_event(&mut buf) {
                Ok(Event::Text(e)) => {
                    self.set_text(e.unescape_and_decode(&reader).unwrap());
                }, 
                Ok(Event::End(ref e)) => {
                    match e.name() {
                        b"c:formatCode" => return,
                        _ => (),
                    }
                },
                Ok(Event::Eof) => panic!("Error not find {} end element", "c:formatCode"),
                Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
                _ => (),
            }
            buf.clear();
        }
    }

    pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
        // c:formatCode
        write_start_tag(writer, "c:formatCode", vec![], false);
        write_text_node(writer, &self.text);
        write_end_tag(writer, "c:formatCode");
    }
}
